@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -54,6 +54,7 @@ namespace Common {
     output->functions.get_param = NULL;
     output->functions.log_param = NULL;
     output->functions.init_comp = NULL;
+    output->functions.init_system_port = NULL;
     output->functions.start = NULL;
     output->functions.control = NULL;
     output->intervals.pre_things_size = 0;
@@ -136,6 +137,8 @@ namespace Common {
       mputstr(dest->functions.log_param, src->functions.log_param);
     dest->functions.init_comp =
       mputstr(dest->functions.init_comp, src->functions.init_comp);
+    dest->functions.init_system_port =
+      mputstr(dest->functions.init_system_port, src->functions.init_system_port);
     dest->functions.start =
       mputstr(dest->functions.start, src->functions.start);
     dest->functions.control =
@@ -167,6 +170,7 @@ namespace Common {
     Free(output->functions.get_param);
     Free(output->functions.log_param);
     Free(output->functions.init_comp);
+    Free(output->functions.init_system_port);
     Free(output->functions.start);
     Free(output->functions.control);
     Free(output->intervals.methods);
