@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -336,13 +336,14 @@ int main(int argc, char *argv[])
   // Leave it relative.
   if (!input_dir) input_dir = ".";
   if (!output_file)	output_file = "output.info";
+  std::string xsd_file_str;
   if (!xsd_file) {
     const char *ttcn3_dir = getenv("TTCN3_DIR");
     if (!ttcn3_dir) {
       std::cerr << "$TTCN3_DIR environment variable is not set" << std::endl;
       param_error = true;
     } else {
-      std::string xsd_file_str = std::string(ttcn3_dir) + P_SEP + std::string("include") + P_SEP + std::string("tcov.xsd");
+      xsd_file_str = std::string(ttcn3_dir) + P_SEP + std::string("include") + P_SEP + std::string("tcov.xsd");
       xsd_file = xsd_file_str.c_str();
     }
   }
