@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -883,6 +883,17 @@ namespace Ttcn {
   }
 
   // ==== AttributeSpec ====
+  
+  AttributeSpec::~AttributeSpec()
+  {
+    if (encodings != NULL) {
+      for (size_t i = 0; i < encodings->size(); ++i) {
+        delete (*encodings)[i];
+      }
+      encodings->clear();
+      delete encodings;
+    }
+  }
 
   AttributeSpec* AttributeSpec::clone() const
   {
@@ -897,8 +908,15 @@ namespace Ttcn {
   void AttributeSpec::dump(unsigned level) const
   {
     DEBUG(level,"spec: %s", spec.c_str());
-    if (!encoding.empty()) {
-      DEBUG(level, "encoding: %s", encoding.c_str());
+    if (encodings != NULL) {
+      string res;
+      for (size_t i = 0; i < encodings->size(); ++i) {
+        if (i != 0) {
+          res += ", ";
+        }
+        res += *(*encodings)[i];
+      }
+      DEBUG(level, "encoding(s): %s", res.c_str());
     }
   }
 
@@ -1203,7 +1221,7 @@ namespace Ttcn {
             "attributes. Modifier ignored.");
         }
       }
-      if (!temp_attrib->get_attribSpec().get_encoding().empty() &&
+      if (temp_attrib->get_attribSpec().get_encodings() != NULL &&
           (legacy_codec_handling ||
            temp_attrib->get_attribKeyword() != SingleWithAttrib::AT_VARIANT)) {
         temp_attrib->error("Invalid attribute format. Dot notation is only "
