@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Szabo, Bence Janos
@@ -13,7 +13,7 @@
 
 OerAST::OerAST() :
   bytes(-1),
-  signed_(false),
+  signed_(true),
   length(-1),
   extendable(false),
   nr_of_root_comps(0),
@@ -33,6 +33,6 @@ OerAST::~OerAST() {
 }
 
 bool OerAST::empty() const {
-  return bytes == -1 && signed_ == false && length == -1 &&
+  return bytes == -1 && signed_ && length == -1 &&
     extendable == false && nr_of_root_comps == 0 && ext_attr_groups.empty() && p.empty();
 }
