@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -62,6 +62,8 @@ RawAST::RawAST(RawAST *other, int default_length){
     presence.fieldName=NULL;
     presence.nElements=0;
     presence.keyList=NULL;
+    forceomit.nElements = 0;
+    forceomit.lists = NULL;
     topleveleind=other->topleveleind;
     toplevel.bitorder=other->toplevel.bitorder;
     length_restrition=other->length_restrition;
@@ -105,6 +107,8 @@ void RawAST::init_rawast(int default_length){
     presence.fieldName=NULL;
     presence.nElements=0;
     presence.keyList=NULL;
+    forceomit.nElements = 0;
+    forceomit.lists = NULL;
     topleveleind=0;
     intx = false;
     stringformat = CharCoding::UNKNOWN;
@@ -121,6 +125,10 @@ RawAST::~RawAST(){
     free_rawAST_tag_list(&taglist);
     free_rawAST_tag_list(&crosstaglist);
     free_rawAST_single_tag(&presence);
+    for (int i = 0; i < forceomit.nElements; ++i) {
+      free_rawAST_field_list(forceomit.lists[i]);
+    }
+    Free(forceomit.lists);
     if(lengthindex!=NULL) {
         for(int a=0;a<lengthindex->nElements;a++) delete lengthindex->names[a];
 	Free(lengthindex->names);
@@ -160,6 +168,14 @@ void RawAST::print_RawAST(){
       }
       printf("\n\r");
     }
+    printf("forceomit:\n\r");
+    for (int i = 0; i < forceomit.nElements; ++i) {
+      for (int j = 0; j < forceomit.lists[i]->nElements; ++j) {
+        printf("%s%s", j > 0 ? "." : "  ",
+          forceomit.lists[i]->names[j]->get_name().c_str());
+      }
+      printf("\n\r");
+    }
     printf("crosstag:\n\r");
     printf("  nElements:%d \n\r",crosstaglist.nElements);
     for(int a=0;a<crosstaglist.nElements;a++){
