@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -94,6 +94,7 @@ typedef struct port_msg_provider {
   const char *name; // provider type's name
   size_t n_out_msg_type_names;
   const char **out_msg_type_names; // provider's out message list
+  boolean realtime;
 } port_msg_prov;
 
 typedef struct port_msg_provider_list {
@@ -116,6 +117,7 @@ typedef struct port_def_tag {
   port_type_t port_type;
   port_msg_prov_list provider_msg_outlist;
   const char **mapper_name;
+  boolean* mapper_realtime;
   size_t n_mapper_name;
   port_msg_mapped_type_list provider_msg_in;
   boolean has_sliding;
@@ -124,6 +126,7 @@ typedef struct port_def_tag {
   char *var_defs;
   char *mapping_func_decls;
   char *mapping_func_defs;
+  boolean realtime;
 } port_def;
 
 #ifdef __cplusplus
