@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -58,7 +58,7 @@ typedef struct{
 
 typedef struct{
     const char* fieldName;
-    int fieldnum;
+    int fieldnum; /* -2 == omit (for JSON only) */
     int nElements;
     rawAST_coding_field_list* fields;
 }rawAST_coding_taglist;
