@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -997,7 +997,8 @@ int Base_Type::TEXT_decode(const TTCN_Typedescriptor_t& p_td,
 
 int Base_Type::RAW_decode(const TTCN_Typedescriptor_t& p_td,
   TTCN_Buffer&, int /* limit */, raw_order_t /* top_bit_ord */,
-  boolean /* no_error */, int /* sel_field */, boolean /* first_call */ )
+  boolean /* no_error */, int /* sel_field */, boolean /* first_call */,
+  const RAW_Force_Omit* /* force_omit */ )
 {
   TTCN_error("RAW decoding requested for type '%s'"
              " which has no RAW decoding method.",p_td.name);
@@ -1026,7 +1027,7 @@ int Base_Type::JSON_encode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer&) c
   return 0;
 }
 
-int Base_Type::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer&, boolean) 
+int Base_Type::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer&, boolean, int) 
 {
   TTCN_error("JSON decoding requested for type '%s' which has no"
              " JSON decoding method.", p_td.name);
