@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -56,6 +56,7 @@ TTCN_EncDec::default_error_behavior[TTCN_EncDec::ET_ALL] = {
   TTCN_EncDec::EB_IGNORE,
   TTCN_EncDec::EB_WARNING,
   TTCN_EncDec::EB_ERROR,
+  TTCN_EncDec::EB_ERROR,
   TTCN_EncDec::EB_ERROR
 };
 
@@ -85,6 +86,7 @@ TTCN_EncDec::error_behavior[TTCN_EncDec::ET_ALL] = {
   TTCN_EncDec::EB_IGNORE,
   TTCN_EncDec::EB_WARNING,
   TTCN_EncDec::EB_ERROR,
+  TTCN_EncDec::EB_ERROR,
   TTCN_EncDec::EB_ERROR
 };
 
@@ -1341,8 +1343,8 @@ unsigned char TTCN_Buffer::get_byte_rev(const unsigned char* data,
 {
   unsigned char ch='\0';
   size_t hossz=(len+7)/8-1;
-  int bit_limit=len%8;
   if(idx>hossz) return ch;
+  const int bit_limit=len%8;
   if(bit_limit==0)return data[hossz-idx];
   ch=data[hossz-idx]<<(8-bit_limit);
   if((hossz-idx)>0) ch|=(data[hossz-idx-1]>>bit_limit)
