@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -29,7 +29,7 @@
 #include "Runtime.hh"
 #include "Charstring.hh"
 
-#ifdef LINUX
+#if defined(LINUX) && !defined(ALPINE_LINUX)
 #include <ucontext.h>
 #include <dlfcn.h>
 #include <execinfo.h>
@@ -41,7 +41,7 @@ using namespace __cxxabiv1;
 
 #endif
 
-#ifdef LINUX
+#if defined(LINUX) && !defined(ALPINE_LINUX)
 
 const size_t MAX_DEPTH=100;
 
