@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -532,7 +532,7 @@ void LoggerPluginManager::fill_common_fields(API::TitanLogEvent& event,
   struct timeval tv;
   if (gettimeofday(&tv, NULL) < 0)
     TTCN_Logger::fatal_error("The gettimeofday() system call failed.");
-  event.timestamp() = API::TimestampType(tv.tv_sec, tv.tv_usec);
+  event.timestamp__() = API::TimestampType(tv.tv_sec, tv.tv_usec);
   TTCN_Logger::source_info_format_t source_info_format =
     TTCN_Logger::get_source_info_format();
   API::TitanLogEvent_sourceInfo__list& srcinfo = event.sourceInfo__list();
@@ -1534,6 +1534,9 @@ void LoggerPluginManager::log_setstate(const char *port_name, translation_port_s
     case PARTIALLY_TRANSLATED:
       setstate.state() = "partially translated";
       break;
+    case DISCARDED:
+      setstate.state() = "discarded";
+      break;
     default:
       TTCN_Logger::fatal_error("LoggerPluginManager::log_setstate(): unexpected port state");
   }
