@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Baji, Laszlo
@@ -186,16 +186,6 @@ OCTETSTRING OCTETSTRING::operator+(const OCTETSTRING_ELEMENT& other_value) const
   return ret_val;
 }
 
-#ifdef TITAN_RUNTIME_2
-OCTETSTRING OCTETSTRING::operator+(const OPTIONAL<OCTETSTRING>& other_value) const
-{
-  if (other_value.is_present()) {
-    return *this + (const OCTETSTRING&)other_value;
-  }
-  TTCN_error("Unbound or omitted right operand of octetstring concatenation.");
-}
-#endif
-
 OCTETSTRING& OCTETSTRING::operator+=(const OCTETSTRING& other_value)
 {
   must_bound("Appending an octetstring value to an unbound octetstring value.");
@@ -509,7 +499,7 @@ OCTETSTRING::operator const unsigned char*() const
 void OCTETSTRING::log() const
 {
   if (val_ptr != NULL) {
-    boolean only_printable = TRUE;
+    boolean only_printable = TTCN_Logger::get_log_format() == TTCN_Logger::LF_LEGACY;
     TTCN_Logger::log_char('\'');
     for (int i = 0; i < val_ptr->n_octets; i++) {
       unsigned char octet = val_ptr->octets_ptr[i];
@@ -1235,14 +1225,14 @@ int OCTETSTRING::RAW_encode(const TTCN_Typedescriptor_t& p_td,
     for (int a = 0; a < blength; a++) bc[a] = val_ptr->octets_ptr[a] << 1;
   }
   else myleaf.body.leaf.data_ptr = val_ptr->octets_ptr;
-  if (p_td.raw->endianness == ORDER_MSB) myleaf.align = -align_length;
-  else myleaf.align = align_length;
+  if (p_td.raw->endianness == ORDER_MSB) myleaf.align = align_length;
+  else myleaf.align = -align_length;
   return myleaf.length = bl + align_length;
 }
 
 int OCTETSTRING::RAW_decode(const TTCN_Typedescriptor_t& p_td,
   TTCN_Buffer& buff, int limit, raw_order_t top_bit_ord, boolean no_err,
-  int /*sel_field*/, boolean /*first_call*/)
+  int /*sel_field*/, boolean /*first_call*/, const RAW_Force_Omit* /*force_omit*/)
 {
   int prepaddlength = buff.increase_pos_padd(p_td.raw->prepadding);
   limit -= prepaddlength;
@@ -1331,7 +1321,7 @@ int OCTETSTRING::JSON_encode(const TTCN_Typedescriptor_t&, JSON_Tokenizer& p_tok
   return enc_len;
 }
 
-int OCTETSTRING::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok, boolean p_silent)
+int OCTETSTRING::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok, boolean p_silent, int)
 {
   json_token_t token = JSON_TOKEN_NONE;
   char* value = 0;
@@ -1518,17 +1508,6 @@ OCTETSTRING OCTETSTRING_ELEMENT::operator+
   return OCTETSTRING(2, result);
 }
 
-#ifdef TITAN_RUNTIME_2
-OCTETSTRING OCTETSTRING_ELEMENT::operator+(
-  const OPTIONAL<OCTETSTRING>& other_value) const
-{
-  if (other_value.is_present()) {
-    return *this + (const OCTETSTRING&)other_value;
-  }
-  TTCN_error("Unbound or omitted right operand of octetstring concatenation.");
-}
-#endif
-
 OCTETSTRING OCTETSTRING_ELEMENT::operator~() const
 {
   must_bound("Unbound octetstring element operand of operator not4b.");
@@ -2016,16 +1995,6 @@ OCTETSTRING_template OCTETSTRING_template::operator+(
   return *this + OCTETSTRING(other_value);
 }
 
-OCTETSTRING_template OCTETSTRING_template::operator+(
-  const OPTIONAL<OCTETSTRING>& other_value) const
-{
-  if (other_value.is_present()) {
-    return *this + (const OCTETSTRING&)other_value;
-  }
-  TTCN_error("Operand of octetstring template concatenation is an "
-    "unbound or omitted record/set field.");
-}
-
 OCTETSTRING_template OCTETSTRING_template::operator+(
   template_sel other_template_sel) const
 {
@@ -2061,16 +2030,6 @@ OCTETSTRING_template operator+(const OCTETSTRING_ELEMENT& left_value,
   return OCTETSTRING(left_value) + right_template;
 }
 
-OCTETSTRING_template operator+(const OPTIONAL<OCTETSTRING>& left_value,
-  const OCTETSTRING_template& right_template)
-{
-  if (left_value.is_present()) {
-    return (const OCTETSTRING&)left_value + right_template;
-  }
-  TTCN_error("Operand of octetstring template concatenation is an "
-    "unbound or omitted record/set field.");
-}
-
 OCTETSTRING_template operator+(template_sel left_template_sel,
   const OCTETSTRING_template& right_template)
 {
@@ -2104,16 +2063,6 @@ OCTETSTRING_template operator+(const OCTETSTRING_ELEMENT& left_value,
   return OCTETSTRING(left_value) + right_template_sel;
 }
 
-OCTETSTRING_template operator+(const OPTIONAL<OCTETSTRING>& left_value,
-  template_sel right_template_sel)
-{
-  if (left_value.is_present()) {
-    return (const OCTETSTRING&)left_value + right_template_sel;
-  }
-  TTCN_error("Operand of octetstring template concatenation is an "
-    "unbound or omitted record/set field.");
-}
-
 OCTETSTRING_template operator+(template_sel left_template_sel,
   const OCTETSTRING& right_value)
 {
@@ -2129,16 +2078,6 @@ OCTETSTRING_template operator+(template_sel left_template_sel,
 {
   return left_template_sel + OCTETSTRING(right_value);
 }
-
-OCTETSTRING_template operator+(template_sel left_template_sel,
-  const OPTIONAL<OCTETSTRING>& right_value)
-{
-  if (right_value.is_present()) {
-    return left_template_sel + (const OCTETSTRING&)right_value;
-  }
-  TTCN_error("Operand of octetstring template concatenation is an "
-    "unbound or omitted record/set field.");
-}
 #endif // TITAN_RUNTIME_2
 
 OCTETSTRING_ELEMENT OCTETSTRING_template::operator[](int index_value)
