@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Baji, Laszlo
@@ -40,7 +40,7 @@
 #include "Error.hh"
 #include "Encdec.hh"
 #include "TCov.hh"
-#ifdef LINUX
+#if defined(LINUX) && !defined(ALPINE_LINUX)
 #include <execinfo.h>
 #endif  
 
@@ -67,7 +67,7 @@ void signal_handler(int signum)
     fprintf(stderr,"%s %s: %s\n",ts,stored_argv,signum==SIGABRT?"Abort was called":"Segmentation fault occurred");
   }
   fflush(stderr);
-#ifdef LINUX
+#if defined(LINUX) && !defined(ALPINE_LINUX)
   int nptrs;
   void *buffer[100];
   nptrs = backtrace(buffer, 100);
