@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Baji, Laszlo
@@ -503,11 +503,29 @@ boolean PORT::port_is_started() {
   return is_started;
 }
 
+void PORT::safe_start()
+{
+  if (!is_started) {
+    activate_port(TRUE);
+    start();
+  }
+}
+
+void PORT::add_port(PORT* /*p*/)
+{
+  TTCN_error("Internal error: Calling PORT::add_port");
+}
+
+void PORT::remove_port(PORT* /*p*/)
+{
+  TTCN_error("Internal error: Calling PORT::remove_port");
+}
+
 PORT* PORT::get_provider_port() {
   return NULL;
 }
 
-alt_status PORT::receive(const COMPONENT_template&, COMPONENT *, Index_Redirect*)
+alt_status PORT::receive(const COMPONENT_template&, COMPONENT *, FLOAT*, Index_Redirect*)
 {
   TTCN_Logger::log_matching_problem(
     TitanLoggerApi::MatchingProblemType_reason::no__incoming__types,
@@ -517,12 +535,12 @@ alt_status PORT::receive(const COMPONENT_template&, COMPONENT *, Index_Redirect*
 }
 
 alt_status PORT::any_receive(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->receive(sender_template, sender_ptr)) {
+      switch (port->receive(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -546,7 +564,8 @@ alt_status PORT::any_receive(const COMPONENT_template& sender_template,
   }
 }
 
-alt_status PORT::check_receive(const COMPONENT_template&, COMPONENT *, Index_Redirect*)
+alt_status PORT::check_receive(const COMPONENT_template&, COMPONENT *, FLOAT*,
+  Index_Redirect*)
 {
   TTCN_Logger::log_matching_problem(
     TitanLoggerApi::MatchingProblemType_reason::no__incoming__types,
@@ -556,12 +575,12 @@ alt_status PORT::check_receive(const COMPONENT_template&, COMPONENT *, Index_Red
 }
 
 alt_status PORT::any_check_receive(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->check_receive(sender_template, sender_ptr)) {
+      switch (port->check_receive(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -585,7 +604,8 @@ alt_status PORT::any_check_receive(const COMPONENT_template& sender_template,
   }
 }
 
-alt_status PORT::trigger(const COMPONENT_template&, COMPONENT *, Index_Redirect*)
+alt_status PORT::trigger(const COMPONENT_template&, COMPONENT *, FLOAT*,
+  Index_Redirect*)
 {
   TTCN_Logger::log_matching_problem(
     TitanLoggerApi::MatchingProblemType_reason::no__incoming__types,
@@ -595,12 +615,12 @@ alt_status PORT::trigger(const COMPONENT_template&, COMPONENT *, Index_Redirect*
 }
 
 alt_status PORT::any_trigger(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->trigger(sender_template, sender_ptr)) {
+      switch (port->trigger(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -626,7 +646,7 @@ alt_status PORT::any_trigger(const COMPONENT_template& sender_template,
   }
 }
 
-alt_status PORT::getcall(const COMPONENT_template&, COMPONENT *, Index_Redirect*)
+alt_status PORT::getcall(const COMPONENT_template&, COMPONENT *, FLOAT*, Index_Redirect*)
 {
 //  ToDo:Unnecessary log matching problem warning removed.
 //  Question: does it unnecessary?
@@ -638,12 +658,12 @@ alt_status PORT::getcall(const COMPONENT_template&, COMPONENT *, Index_Redirect*
 }
 
 alt_status PORT::any_getcall(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->getcall(sender_template, sender_ptr)) {
+      switch (port->getcall(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -667,7 +687,7 @@ alt_status PORT::any_getcall(const COMPONENT_template& sender_template,
   }
 }
 
-alt_status PORT::check_getcall(const COMPONENT_template&, COMPONENT *, Index_Redirect*)
+alt_status PORT::check_getcall(const COMPONENT_template&, COMPONENT *, FLOAT*, Index_Redirect*)
 {
 //  ToDo:Unnecessary log matching problem warning removed.
 //  Question: does it unnecessary
@@ -679,12 +699,12 @@ alt_status PORT::check_getcall(const COMPONENT_template&, COMPONENT *, Index_Red
 }
 
 alt_status PORT::any_check_getcall(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->check_getcall(sender_template, sender_ptr)) {
+      switch (port->check_getcall(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -708,7 +728,7 @@ alt_status PORT::any_check_getcall(const COMPONENT_template& sender_template,
   }
 }
 
-alt_status PORT::getreply(const COMPONENT_template&, COMPONENT *, Index_Redirect*)
+alt_status PORT::getreply(const COMPONENT_template&, COMPONENT *, FLOAT*, Index_Redirect*)
 {
 //  ToDo:Unnecessary log matching problem warning removed.
 //  Question: does it unnecessary
@@ -720,12 +740,12 @@ alt_status PORT::getreply(const COMPONENT_template&, COMPONENT *, Index_Redirect
 }
 
 alt_status PORT::any_getreply(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->getreply(sender_template, sender_ptr)) {
+      switch (port->getreply(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -749,7 +769,7 @@ alt_status PORT::any_getreply(const COMPONENT_template& sender_template,
   }
 }
 
-alt_status PORT::check_getreply(const COMPONENT_template&, COMPONENT *, Index_Redirect*)
+alt_status PORT::check_getreply(const COMPONENT_template&, COMPONENT *, FLOAT*, Index_Redirect*)
 {
 //  ToDo:Unnecessary log matching problem warning removed.
 //  Question: does it unnecessary
@@ -761,12 +781,12 @@ alt_status PORT::check_getreply(const COMPONENT_template&, COMPONENT *, Index_Re
 }
 
 alt_status PORT::any_check_getreply(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->check_getreply(sender_template, sender_ptr)) {
+      switch (port->check_getreply(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -790,7 +810,7 @@ alt_status PORT::any_check_getreply(const COMPONENT_template& sender_template,
   }
 }
 
-alt_status PORT::get_exception(const COMPONENT_template&, COMPONENT *, Index_Redirect*)
+alt_status PORT::get_exception(const COMPONENT_template&, COMPONENT *, FLOAT*, Index_Redirect*)
 {
 //  ToDo:Unnecessary log matching problem warning removed.
 //  Question: does it unnecessary
@@ -802,12 +822,12 @@ alt_status PORT::get_exception(const COMPONENT_template&, COMPONENT *, Index_Red
 }
 
 alt_status PORT::any_catch(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->get_exception(sender_template, sender_ptr)) {
+      switch (port->get_exception(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -832,7 +852,7 @@ alt_status PORT::any_catch(const COMPONENT_template& sender_template,
 }
 
 alt_status PORT::check_catch(const COMPONENT_template& ,
-  COMPONENT *, Index_Redirect*)
+  COMPONENT *, FLOAT*, Index_Redirect*)
 {
 //  ToDo:Unnecessary log matching problem warning removed.
 //  Question: does it unnecessary
@@ -844,12 +864,12 @@ alt_status PORT::check_catch(const COMPONENT_template& ,
 }
 
 alt_status PORT::any_check_catch(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->check_catch(sender_template, sender_ptr)) {
+      switch (port->check_catch(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -874,11 +894,11 @@ alt_status PORT::any_check_catch(const COMPONENT_template& sender_template,
 }
 
 alt_status PORT::check(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr, Index_Redirect*)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect, Index_Redirect*)
 {
   alt_status ret_val = ALT_NO;
   // the procedure-based queue must have the higher priority
-  switch (check_getcall(sender_template, sender_ptr)) {
+  switch (check_getcall(sender_template, sender_ptr, timestamp_redirect)) {
   case ALT_YES:
     return ALT_YES;
   case ALT_MAYBE:
@@ -893,7 +913,7 @@ alt_status PORT::check(const COMPONENT_template& sender_template,
   if (ret_val != ALT_MAYBE) {
     // don't try getreply if the procedure-based queue is empty
     // (i.e. check_getcall() returned ALT_MAYBE)
-    switch (check_getreply(sender_template, sender_ptr)) {
+    switch (check_getreply(sender_template, sender_ptr, timestamp_redirect)) {
     case ALT_YES:
       return ALT_YES;
     case ALT_MAYBE:
@@ -909,7 +929,7 @@ alt_status PORT::check(const COMPONENT_template& sender_template,
   if (ret_val != ALT_MAYBE) {
     // don't try catch if the procedure-based queue is empty
     // (i.e. check_getcall() or check_getreply() returned ALT_MAYBE)
-    switch (check_catch(sender_template, sender_ptr)) {
+    switch (check_catch(sender_template, sender_ptr, timestamp_redirect)) {
     case ALT_YES:
       return ALT_YES;
     case ALT_MAYBE:
@@ -922,7 +942,7 @@ alt_status PORT::check(const COMPONENT_template& sender_template,
         "unexpected status code on port %s.", port_name);
     }
   }
-  switch (check_receive(sender_template, sender_ptr)) {
+  switch (check_receive(sender_template, sender_ptr, timestamp_redirect)) {
   case ALT_YES:
     return ALT_YES;
   case ALT_MAYBE:
@@ -938,12 +958,12 @@ alt_status PORT::check(const COMPONENT_template& sender_template,
 }
 
 alt_status PORT::any_check(const COMPONENT_template& sender_template,
-  COMPONENT *sender_ptr)
+  COMPONENT *sender_ptr, FLOAT* timestamp_redirect)
 {
   if (list_head != NULL) {
     alt_status ret_val = ALT_NO;
     for (PORT *port = list_head; port != NULL; port = port->list_next) {
-      switch (port->check(sender_template, sender_ptr)) {
+      switch (port->check(sender_template, sender_ptr, timestamp_redirect)) {
       case ALT_YES:
         return ALT_YES;
       case ALT_MAYBE:
@@ -2493,6 +2513,9 @@ void PORT::terminate_local_connection(const char *src_port,
 
 void PORT::map_port(const char *component_port, const char *system_port, boolean translation)
 {
+  if (translation == TRUE) {
+    TTCN_Runtime::initialize_system_port(system_port);
+  }
   const char *port_name = translation == FALSE ? component_port : system_port;
   PORT *port_ptr = lookup_by_name(port_name, translation);
   if (port_ptr == NULL) TTCN_error("Map operation refers to "
@@ -2505,17 +2528,21 @@ void PORT::map_port(const char *component_port, const char *system_port, boolean
   } else {
     port_ptr->map(component_port, translation);
   }
-  if (!TTCN_Runtime::is_single()) {
-    if (translation == FALSE) {
-      TTCN_Communication::send_mapped(component_port, system_port, translation);
-    } else {
-      TTCN_Communication::send_mapped(system_port, component_port, translation);
+  if (translation == TRUE) {
+    PORT* other_port_ptr = lookup_by_name(component_port, FALSE);
+    if (other_port_ptr == NULL) {
+      TTCN_error("Map operation refers to non-existent port %s.", port_name);
     }
+    other_port_ptr->add_port(port_ptr);
+    port_ptr->add_port(other_port_ptr);
   }
 }
 
 void PORT::unmap_port(const char *component_port, const char *system_port, boolean translation)
 {
+  if (translation == TRUE) {
+    TTCN_Runtime::initialize_system_port(system_port);
+  }
   const char *port_name = translation == FALSE ? component_port : system_port;
   PORT *port_ptr = lookup_by_name(port_name, translation);
   if (port_ptr == NULL) TTCN_error("Unmap operation refers to "
@@ -2525,8 +2552,14 @@ void PORT::unmap_port(const char *component_port, const char *system_port, boole
   } else {
     port_ptr->unmap(component_port, translation);
   }
-  if (!TTCN_Runtime::is_single())
-    TTCN_Communication::send_unmapped(component_port, system_port, translation);
+  if (translation == TRUE) {
+    PORT* other_port_ptr = lookup_by_name(component_port, FALSE);
+    if (other_port_ptr == NULL) {
+      TTCN_error("Unmap operation refers to non-existent port %s.", port_name);
+    }
+    other_port_ptr->remove_port(port_ptr);
+    port_ptr->remove_port(other_port_ptr);
+  }
 }
 
 boolean PORT::check_port_state(const CHARSTRING& type) const
