@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -146,7 +146,7 @@ void JUnitLogger2::log(const TitanLoggerApi::TitanLogEvent& event,
         case TitanLoggerApi::TestcaseEvent_choice::ALT_testcaseStarted: {
           testcase.tc_name = tcev.testcaseStarted().testcase__name();
           // remember the start time
-          testcase.tc_start = 1000000LL * (long long)event.timestamp().seconds() + (long long)event.timestamp().microSeconds();
+          testcase.tc_start = 1000000LL * (long long)event.timestamp__().seconds() + (long long)event.timestamp__().microSeconds();
           break; }
 
         case TitanLoggerApi::TestcaseEvent_choice::ALT_testcaseFinished: {
@@ -154,7 +154,7 @@ void JUnitLogger2::log(const TitanLoggerApi::TitanLogEvent& event,
           testcase.reason = escape_xml_element(tct.reason());
           testcase.module_name = tct.name().module__name();
           
-          const TitanLoggerApi::TimestampType& ts = event.timestamp();
+          const TitanLoggerApi::TimestampType& ts = event.timestamp__();
           long long tc_end = 1000000LL * (long long)ts.seconds() + (long long)ts.microSeconds();
           testcase.time = (tc_end - testcase.tc_start) / 1000000.0;
 
@@ -236,6 +236,13 @@ void TestCase::writeTestCase(FILE* file_stream_) const{
       fprintf(file_stream_, "    <error type='DTE'>%s</error>\n", dte_reason.data());
       fprintf(file_stream_, "  </testcase>\n");
       break; }
+    case Inconc:  {
+      fprintf(file_stream_, "  <testcase classname='%s' name='%s' time='%f'>\n", module_name.data(), tc_name.data(), time);
+      fprintf(file_stream_, "    <failure type='inconclusive-verdict'>%s\n", reason.data());
+      fprintf(file_stream_, "%s\n", stack_trace.data());
+      fprintf(file_stream_, "    </failure>\n");
+      fprintf(file_stream_, "  </testcase>\n");
+      break; }
     default: 
       fprintf(file_stream_, "  <testcase classname='%s' name='%s' time='%f'/>\n", module_name.data(), tc_name.data(), time);
       break;
