@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -431,7 +431,7 @@ string TSTLogger::post_message(std::map<std::string,std::string> req_params, con
     client.close_connection();
     return response;
   }
-  catch (SocketException exc) {
+  catch (SocketException &exc) {
     cerr << this->name_ << ": " << "HTTP error: " << exc.getMessage() << " (" << exc.getReason() << ")\n";
   }
   return "";
@@ -458,12 +458,12 @@ void TSTLogger::log(const TitanLoggerApi::TitanLogEvent& event,
     switch (tec.get_selection()) {
     case TitanLoggerApi::TestcaseEvent_choice::ALT_testcaseStarted:
       if (is_main_proc()) {
-        log_testcase_start(tec.testcaseStarted(), event.timestamp());
+        log_testcase_start(tec.testcaseStarted(), event.timestamp__());
       }
       break;
     case TitanLoggerApi::TestcaseEvent_choice::ALT_testcaseFinished:
       if (is_main_proc()) {
-        log_testcase_stop(tec.testcaseFinished(), event.timestamp());
+        log_testcase_stop(tec.testcaseFinished(), event.timestamp__());
       }
       break;
     default:
