@@ -1,9 +1,9 @@
 /******************************************************************************
- * Copyright (c) 2000-2017 Ericsson Telecom AB
+ * Copyright (c) 2000-2018 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/org/documents/epl-2.0/EPL-2.0.html
  *
  * Contributors:
  *   Balasko, Jeno
@@ -38,6 +38,7 @@ bool g_flag_used = true;
 bool h_flag_used = false;
 bool m_flag_used = false;
 bool n_flag_used = false; // Undocumented. Internal use only with makefilegen
+bool o_flag_used = false;
 bool p_flag_used = false;
 bool s_flag_used = false;
 bool t_flag_used = false;
@@ -74,7 +75,7 @@ int main(int argc, char **argv) {
   char c;
   opterr = 0;
 
-  while ((c = getopt(argc, argv, "cdef:ghJ:mnpqstvwxz")) != -1) {
+  while ((c = getopt(argc, argv, "cdef:ghJ:mnopqstvwxz")) != -1) {
     switch (c) {
       case 'c':
         c_flag_used = true;
@@ -102,6 +103,9 @@ int main(int argc, char **argv) {
       case 'n':
         n_flag_used = true;
         break;
+      case 'o':
+        o_flag_used = true;
+        break;
       case 'p':
         p_flag_used = true;
         break;
@@ -244,7 +248,7 @@ static void printProductinfo() {
 
 static void printUsage(const char * argv0) {
   fprintf(stderr, "\n"
-    "usage: %s [-ceghmpstVwx] [-f file] [-J file] schema.xsd ...\n"
+    "usage: %s [-ceghmopstVwx] [-f file] [-J file] schema.xsd ...\n"
     "	or %s -v\n"
     "\n"
     "OPTIONS:\n"
@@ -253,7 +257,8 @@ static void printUsage(const char * argv0) {
     "	-f|J file:	the names of XSD files are taken from file instead of the command line\n"
     "	-g:		generate TTCN-3 code disallowing element substitution\n"
     "	-h:		generate TTCN-3 code allowing type substitution\n"
-    "	-m:		generate only the UsefulTtcn3Types and XSD predefined modules"
+    "	-m:		generate only the UsefulTtcn3Types and XSD predefined modules\n"
+    "	-o:		generate all definitions into one module (called XSD_Definitions)\n"
     "	-p:		do not generate the UsefulTtcn3Types and XSD predefined modules\n"
     "	-q:		quiet mode - disable the issue of status messages\n"
     "	-s:		parse and validate only - no TTCN-3 module generation\n"
